@@ -16,7 +16,7 @@ register_worker({ phase => 'check' }, sub {
   vars->{'port'} = get_port($device, $pn)
     or return Status->error("Unknown port name [$pn] on device $device");
 
-  my $port_reconfig_check = port_reconfig_check(vars->{'port'});
+  my $port_reconfig_check = port_reconfig_check(vars->{'port'}, $device, $job->username);
   return Status->error("Cannot alter port: $port_reconfig_check")
     if $port_reconfig_check;
 
